# matplotrust examples

## line plots

Line plots are generated with `line_plot::<T, U>()`.
Below is an example:

```rust
extern crate matplotrust;

use matplotrust::*;

fn main() {
    let x = vec![1, 2, 3, 4];
    let y = vec![0.1, 0.2, 0.5, 0.3];
    let lp = line_plot::<i32, f64>(x, y, None);
    let mut figure = Figure::new();
    figure.add_plot(lp.clone());
    figure.add_plot(lp.clone());
    print!("{:?}", figure.save("./examples/figures/lineplot_basic.png"));
}
```

which will generate

![simple scatter](figures/lineplot_basic.png)

## histograms

Histograms can be created with `histogram::<U>()`. For instance:

```rust
extern crate matplotrust;

use matplotrust::*;

fn main() {
         let mut source = source::default();
         let gaussian = Gaussian::new(0.0, 2.0);
         let mut sampler = Independent(&gaussian, &mut source);
         let x = sampler.take(500).collect::<Vec<_>>();
         let plot = histogram::<f64>(x, None);
         let mut figure = Figure::new();
         figure.add_plot(plot.clone());
         print!("{:?}", figure.save("./examples/figures/histogram_default_bins.png", None));
}
```

will generate

![simple scatter](figures/histogram_default_bins.png)

The number of bins can be configured with

```rust
let plot = histogram::<f64>(x, 100);
```

which in turn will generate

![simple scatter](figures/histogram_custom_bins.png)
